@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: ohbci.c 979 2006-02-04 01:47:12Z aquamaniac $
+    cvs         : $Id: ohbci.c 1108 2007-01-09 14:52:56Z christian $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -228,7 +228,7 @@ GWEN_CRYPTTOKEN *GWEN_CryptTokenOHBCI_new(GWEN_PLUGIN_MANAGER *pm,
 
 
 
-void GWEN_CryptTokenOHBCI_FreeData(void *bp, void *p) {
+void GWENHYWFAR_CB GWEN_CryptTokenOHBCI_FreeData(void *bp, void *p) {
   GWEN_CRYPTTOKEN_OHBCI *lct;
 
   lct=(GWEN_CRYPTTOKEN_OHBCI*) p;
