@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: ohbci_l.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: ohbci_l.h,v 1.2 2005/07/26 16:13:14 aquamaniac Exp $
+    cvs         : $Id: ohbci_l.h 794 2005-07-26 16:13:16Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
