@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: logger.c 1067 2006-05-22 15:25:23Z christian $
+    cvs         : $Id: logger.c 1088 2006-09-20 17:05:48Z martin $
     begin       : Sun Dec 05 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -152,14 +152,15 @@ GWEN_LOGGER *GWEN_LoggerDomain_GetLogger(const char *name) {
     return ld->logger;
   }
   ld=GWEN_LoggerDomain_new(name);
-  ld->logger=GWEN_Logger_new();
+  ld->logger=GWEN_Logger_new(ld);
+
   GWEN_LoggerDomain_Add(ld);
   return ld->logger;
 }
 
 
 
-GWEN_LOGGER *GWEN_Logger_new(){
+GWEN_LOGGER *GWEN_Logger_new(GWEN_LOGGER_DOMAIN *domain){
   GWEN_LOGGER *lg;
 
   GWEN_NEW_OBJECT(GWEN_LOGGER, lg);
@@ -167,6 +168,7 @@ GWEN_LOGGER *GWEN_Logger_new(){
   lg->enabled=1;
   lg->logType=GWEN_LoggerType_Console;
   lg->logLevel=GWEN_LoggerLevel_Error;
+  lg->domain=domain;
   return lg;
 }
 
@@ -291,6 +293,9 @@ void GWEN_Logger_Close(const char *logDomain){
   closelog();
 #endif
   lg->open=0;
+  /* remove logdomain after it has been closed */
+  GWEN_LoggerDomain_Del(lg->domain);
+  GWEN_LoggerDomain_free(lg->domain);
 }
 
 
@@ -629,6 +634,20 @@ void GWEN_Logger_SetFilename(const char *logDomain, const char *name){
 
 
 
+GWEN_LOGGERFUNCTIONLOG GWEN_Logger_SetLogFunction(const char *logDomain,
+						  GWEN_LOGGERFUNCTIONLOG fn){
+  GWEN_LOGGER *lg;
+  GWEN_LOGGERFUNCTIONLOG oldFn;
+
+  lg=GWEN_LoggerDomain_GetLogger(logDomain);
+  assert(lg);
+  oldFn=lg->logFunction;
+  lg->logFunction=fn;
+  return oldFn;
+}
+
+
+
 GWEN_LOGGER_LEVEL GWEN_Logger_Name2Level(const char *name) {
   if (strcasecmp(name, "emergency")==0)
     return GWEN_LoggerLevel_Emergency;
