@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: plugindescr.c 1067 2006-05-22 15:25:23Z christian $
+ cvs         : $Id: plugindescr.c 1161 2007-02-16 12:30:24Z christian $
  begin       : Thu Apr 03 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -460,7 +460,7 @@ int GWEN_LoadPluginDescrsByType(const char *path,
 
 	  GWEN_Buffer_Crop(nbuf, 0, pathLen);
 	  GWEN_Buffer_SetPos(nbuf, pathLen);
-	  GWEN_Buffer_AppendByte(nbuf, '/');
+	  GWEN_Buffer_AppendByte(nbuf, GWEN_DIR_SEPARATOR);
 	  GWEN_Buffer_AppendString(nbuf, nbuffer);
 
 	  if (stat(GWEN_Buffer_GetStart(nbuf), &st)) {
@@ -499,7 +499,7 @@ int GWEN_LoadPluginDescrsByType(const char *path,
                     const char *l;
 
                     l=GWEN_StringListEntry_Data(se);
-                    DBG_NOTICE(GWEN_LOGDOMAIN, "Trying locale \"%s\"", l);
+                    DBG_DEBUG(GWEN_LOGDOMAIN, "Trying locale \"%s\"", l);
                     assert(l);
                     n=GWEN_XMLNode_FindFirstTag(node, "plugin", "lang", l);
                     if (n)
