@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: crypt.c,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: crypt.c,v 1.35 2005/09/29 03:21:55 aquamaniac Exp $
+ cvs         : $Id: crypt.c 978 2006-02-03 17:41:49Z aquamaniac $
  begin       : Thu Nov 06 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -49,7 +49,6 @@
 static int gwen_crypt_is_initialized=0;
 static GWEN_ERRORTYPEREGISTRATIONFORM *gwen_crypt_errorform=0;
 
-
 static GWEN_CRYPTKEY_PROVIDER *gwen_crypt_providers=0;
 
 #define GWEN_RANDSTATE_BUFSIZE 256
@@ -172,6 +171,8 @@ GWEN_ERRORCODE GWEN_Crypt_ModuleFini(){
 
 
 
+
+
 GWEN_CRYPTKEY *GWEN_CryptKey_new(){
   GWEN_CRYPTKEY *ck;
 
@@ -297,7 +298,7 @@ unsigned int GWEN_CryptKey_GetChunkSize(const GWEN_CRYPTKEY *key){
 
 
 
-GWEN_CRYPTKEY *GWEN_CryptKey_FromDb(GWEN_DB_NODE *db){
+GWEN_CRYPTKEY *GWEN_CryptKey_fromDb(GWEN_DB_NODE *db){
   GWEN_DB_NODE *gr;
   GWEN_CRYPTKEY *key;
   GWEN_ERRORCODE err;
@@ -307,7 +308,8 @@ GWEN_CRYPTKEY *GWEN_CryptKey_FromDb(GWEN_DB_NODE *db){
     DBG_INFO(GWEN_LOGDOMAIN, "Could not create key");
     return 0;
   }
-  if (GWEN_KeySpec_FromDb(key->keyspec, db)) {
+  key->keyspec=GWEN_KeySpec_fromDb(db);
+  if (!key->keyspec) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Could not create keyspec from DB");
     GWEN_CryptKey_free(key);
     return 0;
@@ -330,14 +332,14 @@ GWEN_CRYPTKEY *GWEN_CryptKey_FromDb(GWEN_DB_NODE *db){
 
 
 
-GWEN_ERRORCODE GWEN_CryptKey_ToDb(const GWEN_CRYPTKEY *key,
+GWEN_ERRORCODE GWEN_CryptKey_toDb(const GWEN_CRYPTKEY *key,
                                   GWEN_DB_NODE *db,
                                   int pub){
   GWEN_DB_NODE *gr;
 
   assert(key);
   assert(key->usage);
-  if (GWEN_KeySpec_ToDb(key->keyspec, db)) {
+  if (GWEN_KeySpec_toDb(key->keyspec, db)) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Could not store keyspec in DB");
     return GWEN_Error_new(0,
                           GWEN_ERROR_SEVERITY_ERR,
@@ -442,6 +444,8 @@ GWEN_ERRORCODE GWEN_CryptKey_Generate(GWEN_CRYPTKEY *key,
   assert(key->usage);
   assert(key->generateKeyFn);
   err=key->generateKeyFn(key, keylength);
+  if (GWEN_Error_IsOk(err))
+    GWEN_CryptKey_SetKeyLength(key, keylength);
   return err;
 }
 
@@ -604,6 +608,24 @@ void GWEN_CryptKey_SetVersion(GWEN_CRYPTKEY *key,
 
 
 
+unsigned int GWEN_CryptKey_GetKeyLength(const GWEN_CRYPTKEY *key) {
+  assert(key);
+  assert(key->usage);
+  assert(key->keyspec);
+  return GWEN_KeySpec_GetKeyLength(key->keyspec);
+}
+
+
+
+void GWEN_CryptKey_SetKeyLength(GWEN_CRYPTKEY *key, unsigned int i) {
+  assert(key);
+  assert(key->usage);
+  assert(key->keyspec);
+  GWEN_KeySpec_SetKeyLength(key->keyspec, i);
+}
+
+
+
 void *GWEN_CryptKey_GetKeyData(const GWEN_CRYPTKEY *key){
   assert(key);
   assert(key->usage);
@@ -859,7 +881,7 @@ GWEN_CRYPTKEY_PROVIDER *GWEN_CryptProvider_new(){
 void GWEN_CryptProvider_free(GWEN_CRYPTKEY_PROVIDER *pr){
   if (pr) {
     free(pr->name);
-    free(pr);
+    GWEN_FREE_OBJECT(pr);
   }
 }
 
@@ -980,3 +1002,9 @@ void GWEN_CryptKey_List2_freeAll(GWEN_CRYPTKEY_LIST2 *stl) {
 
 
 
+int GWEN_Crypt_KeyToDb(const GWEN_CRYPTKEY *key, GWEN_DB_NODE *db) {
+  return GWEN_CryptKey_toDb(key, db, 1);
+}
+
+
+
