@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: cryptssl_rmd160.c 517 2004-08-20 09:17:29Z aquamaniac $
+ cvs         : $Id: cryptssl_rmd160.c 1110 2007-01-09 15:56:41Z christian $
  begin       : Thu Nov 06 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -70,7 +70,7 @@ GWEN_MD *GWEN_MdRmd160_new(){
 
 
 
-void GWEN_MdRmd160_FreeData(GWEN_MD *md){
+void GWENHYWFAR_CB GWEN_MdRmd160_FreeData(GWEN_MD *md){
   RIPEMD160_CTX *ctx;
 
   if (md) {
