@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: cryptssl_sha1.c 722 2005-03-25 17:35:28Z aquamaniac $
+ cvs         : $Id: cryptssl_sha1.c 1110 2007-01-09 15:56:41Z christian $
  begin       : Thu Nov 06 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -70,7 +70,7 @@ GWEN_MD *GWEN_MdSha1_new(){
 
 
 
-void GWEN_MdSha1_FreeData(GWEN_MD *md){
+void GWENHYWFAR_CB GWEN_MdSha1_FreeData(GWEN_MD *md){
   SHA_CTX *ctx;
 
   if (md) {
