@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: ct_file.c 987 2006-02-14 02:10:29Z aquamaniac $
+    cvs         : $Id: ct_file.c 1108 2007-01-09 14:52:56Z christian $
     begin       : Wed Mar 16 2005
     copyright   : (C) 2005 by Martin Preuss
     email       : martin@libchipcard.de
@@ -271,7 +271,7 @@ GWEN_CRYPTTOKEN *GWEN_CryptTokenFile_new(GWEN_PLUGIN_MANAGER *pm,
 
 
 
-void GWEN_CryptTokenFile_FreeData(void *bp, void *p) {
+void GWENHYWFAR_CB GWEN_CryptTokenFile_FreeData(void *bp, void *p) {
   GWEN_CRYPTTOKEN_FILE *lct;
 
   lct=(GWEN_CRYPTTOKEN_FILE*)p;
