@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: ct_file_p.h 978 2006-02-03 17:41:49Z aquamaniac $
+    cvs         : $Id: ct_file_p.h 1108 2007-01-09 14:52:56Z christian $
     begin       : Wed Mar 16 2005
     copyright   : (C) 2005 by Martin Preuss
     email       : martin@libchipcard.de
@@ -64,7 +64,7 @@ struct GWEN_CRYPTTOKEN_FILE {
 
 };
 
-void GWEN_CryptTokenFile_FreeData(void *bp, void *p);
+void GWENHYWFAR_CB GWEN_CryptTokenFile_FreeData(void *bp, void *p);
 
 int GWEN_CryptTokenFile__OpenFile(GWEN_CRYPTTOKEN *ct, int wr);
 int GWEN_CryptTokenFile__CloseFile(GWEN_CRYPTTOKEN *ct);
