@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: gwenhywfar.c 1048 2006-05-17 17:15:35Z martin $
+ cvs         : $Id: gwenhywfar.c 1096 2006-10-11 09:07:45Z christian $
  begin       : Thu Sep 11 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -63,6 +63,7 @@
 
 #include "storage/st_storage_l.h"
 
+#include "binreloc.h"
 
 /* for regkey stuff */
 #ifdef OS_WIN32
@@ -84,18 +85,36 @@
 
 
 static unsigned int gwen_is_initialized=0;
+static int gwen_binreloc_initialized=0;
 
+char *GWEN__get_plugindir (const char *default_dir);
 
 GWEN_ERRORCODE GWEN_Init() {
   GWEN_ERRORCODE err;
 
   if (gwen_is_initialized==0) {
+    char *tmp;
+
     err=GWEN_Memory_ModuleInit();
     if (!GWEN_Error_IsOk(err))
       return err;
     err=GWEN_Logger_ModuleInit();
     if (!GWEN_Error_IsOk(err))
       return err;
+
+    if (gwen_binreloc_initialized==0) {
+      BrInitError br_error;
+
+      /* Init binreloc. Note: It is not totally clear whether the correct
+       function might still be br_init() instead of br_init_lib(). */
+      if (!br_init_lib(&br_error)) {
+        DBG_INFO(GWEN_LOGDOMAIN, "Error on br_init: %d\n", br_error);
+        gwen_binreloc_initialized=-1;
+      }
+      else
+        gwen_binreloc_initialized=1;
+    }
+
     GWEN_Error_ModuleInit();
 
     err=GWEN_PathManager_ModuleInit();
@@ -115,10 +134,12 @@ GWEN_ERRORCODE GWEN_Init() {
 				       GWEN_PM_INSTALLDIR,
 				       GWEN_REGKEY_PATHS,
 				       GWEN_REGNAME_PREFIX);
+    tmp = br_find_prefix (GWEN_PREFIX_DIR);
     GWEN_PathManager_AddPath(GWEN_PM_LIBNAME,
                              GWEN_PM_LIBNAME,
                              GWEN_PM_INSTALLDIR,
-                             GWEN_PREFIX_DIR);
+                             tmp);
+    free (tmp);
 
     /* $sysconfdir e.g. "/etc" */
     GWEN_PathManager_DefinePath(GWEN_PM_LIBNAME, GWEN_PM_SYSCONFDIR);
@@ -127,10 +148,12 @@ GWEN_ERRORCODE GWEN_Init() {
 				       GWEN_PM_SYSCONFDIR,
 				       GWEN_REGKEY_PATHS,
 				       GWEN_REGNAME_SYSCONFDIR);
+    tmp = br_find_etc_dir (GWEN_SYSCONF_DIR);
     GWEN_PathManager_AddPath(GWEN_PM_LIBNAME,
                              GWEN_PM_LIBNAME,
                              GWEN_PM_SYSCONFDIR,
-                             GWEN_SYSCONF_DIR);
+                             tmp);
+    free (tmp);
 
     /* $localedir e.g. "/usr/share/locale" */
     GWEN_PathManager_DefinePath(GWEN_PM_LIBNAME, GWEN_PM_LOCALEDIR);
@@ -139,10 +162,12 @@ GWEN_ERRORCODE GWEN_Init() {
 				       GWEN_PM_LOCALEDIR,
 				       GWEN_REGKEY_PATHS,
 				       GWEN_REGNAME_LOCALEDIR);
+    tmp = br_find_locale_dir (LOCALEDIR);
     GWEN_PathManager_AddPath(GWEN_PM_LIBNAME,
                              GWEN_PM_LIBNAME,
                              GWEN_PM_LOCALEDIR,
-                             LOCALEDIR);
+                             tmp);
+    free (tmp);
 
     /* $libdir e.g. "/usr/lib" */
     GWEN_PathManager_DefinePath(GWEN_PM_LIBNAME, GWEN_PM_LIBDIR);
@@ -151,10 +176,12 @@ GWEN_ERRORCODE GWEN_Init() {
 				       GWEN_PM_LIBDIR,
 				       GWEN_REGKEY_PATHS,
 				       GWEN_REGNAME_LIBDIR);
+    tmp = br_find_lib_dir (LIBDIR);
     GWEN_PathManager_AddPath(GWEN_PM_LIBNAME,
                              GWEN_PM_LIBNAME,
                              GWEN_PM_LIBDIR,
-                             LIBDIR);
+                             tmp);
+    free (tmp);
 
     /* $plugindir e.g. "/usr/lib/gwenhywfar/plugins/0" */
     GWEN_PathManager_DefinePath(GWEN_PM_LIBNAME, GWEN_PM_PLUGINDIR);
@@ -163,10 +190,12 @@ GWEN_ERRORCODE GWEN_Init() {
 				       GWEN_PM_PLUGINDIR,
 				       GWEN_REGKEY_PATHS,
 				       GWEN_REGNAME_PLUGINDIR);
+    tmp = GWEN__get_plugindir (PLUGINDIR);
     GWEN_PathManager_AddPath(GWEN_PM_LIBNAME,
                              GWEN_PM_LIBNAME,
                              GWEN_PM_PLUGINDIR,
-                             PLUGINDIR);
+                             tmp);
+    free (tmp);
 
     /* Initialize other modules. */
     DBG_DEBUG(GWEN_LOGDOMAIN, "Initializing I18N module");
@@ -485,8 +514,26 @@ int GWEN_GetPluginPath(GWEN_BUFFER *pbuf) {
   return 0;
 }
 
+/** Construct the gwenhywfar_plugindir directory path with runtime
+    lookup of the initial $libdir. */
+char *GWEN__get_plugindir (const char *default_dir)
+{
+  char *result, *libdir, *pkglibdir, *tmp;
 
+  libdir = br_find_lib_dir (NULL);
+  if (libdir == (char *) NULL)
+    /* BinReloc not initialized, use default hard-coded path. */
+    return strdup (default_dir);
 
+  pkglibdir = br_build_path (libdir, PACKAGE); /* defined in config.h */
+  tmp = br_build_path (pkglibdir, "plugins");
+  result = br_build_path (tmp, GWENHYWFAR_SO_EFFECTIVE_STR);
 
+  free (libdir);
+  free (pkglibdir);
+  free (tmp);
+
+  return result;
+}
 
 
