@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: bio_file.c 1067 2006-05-22 15:25:23Z christian $
+ cvs         : $Id: bio_file.c 1108 2007-01-09 14:52:56Z christian $
  begin       : Fri Feb 07 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -158,7 +158,7 @@ GWEN_ERRORCODE GWEN_BufferedIO_File__Close(GWEN_BUFFEREDIO *dm){
 
 
 
-void GWEN_BufferedIO_File_FreeData(void *bp, void *p) {
+void GWENHYWFAR_CB GWEN_BufferedIO_File_FreeData(void *bp, void *p) {
   GWEN_BUFFEREDIO_FILE *bft;
 
   bft=(GWEN_BUFFEREDIO_FILE*)p;
