@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: bio_file_p.h 303 2004-04-08 10:37:38Z aquamaniac $
+ cvs         : $Id: bio_file_p.h 1108 2007-01-09 14:52:56Z christian $
  begin       : Fri Feb 07 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -54,7 +54,7 @@ GWEN_ERRORCODE GWEN_BufferedIO_File__Write(GWEN_BUFFEREDIO *dm,
 
 GWEN_ERRORCODE GWEN_BufferedIO_File__Close(GWEN_BUFFEREDIO *dm);
 
-void GWEN_BufferedIO_File_FreeData(void *bp, void *p);
+void GWENHYWFAR_CB GWEN_BufferedIO_File_FreeData(void *bp, void *p);
 
 
 
