@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: bio_socket.c 957 2005-12-23 01:43:18Z aquamaniac $
+ cvs         : $Id: bio_socket.c 1108 2007-01-09 14:52:56Z christian $
  begin       : Fri Feb 07 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -271,7 +271,7 @@ GWEN_ERRORCODE GWEN_BufferedIO_Socket__Close(GWEN_BUFFEREDIO *dm){
 
 
 
-void GWEN_BufferedIO_Socket_FreeData(void *bp, void *p) {
+void GWENHYWFAR_CB GWEN_BufferedIO_Socket_FreeData(void *bp, void *p) {
   GWEN_BUFFEREDIO_SOCKET *bft;
 
   bft=(GWEN_BUFFEREDIO_SOCKET*)p;
