@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: nl_http.c 1024 2006-03-27 12:25:01Z cstim $
+    cvs         : $Id: nl_http.c 1108 2007-01-09 14:52:56Z christian $
     begin       : Mon Feb 09 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -92,7 +92,7 @@ GWEN_NETLAYER *GWEN_NetLayerHttp_new(GWEN_NETLAYER *baseLayer) {
 
 
 
-void GWEN_NetLayerHttp_FreeData(void *bp, void *p) {
+void GWENHYWFAR_CB GWEN_NetLayerHttp_FreeData(void *bp, void *p) {
   GWEN_NL_HTTP *nld;
 
   nld=(GWEN_NL_HTTP*)p;
