@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: gwentime_all.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: gwentime_all.c,v 1.15 2005/08/22 21:52:09 aquamaniac Exp $
+    cvs         : $Id: gwentime_all.c 843 2005-08-22 21:52:09Z aquamaniac $
     begin       : Sun Nov 23 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
