@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: inetsocket.c 978 2006-02-03 17:41:49Z aquamaniac $
+    cvs         : $Id: inetsocket.c 1091 2006-10-02 21:37:10Z martin $
     begin       : Tue Oct 02 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -878,7 +878,7 @@ GWEN_ERRORCODE GWEN_SocketSet_AddSocket(GWEN_SOCKETSET *ssp,
   assert(ssp);
   assert(sp);
   if (sp->socket==-1) {
-    DBG_ERROR(GWEN_LOGDOMAIN, "Socket is not connected, can not add");
+    DBG_INFO(GWEN_LOGDOMAIN, "Socket is not connected, can not add");
     return GWEN_Error_new(0,
                           GWEN_ERROR_SEVERITY_ERR,
                           GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
@@ -1001,7 +1001,7 @@ GWEN_ERRORCODE GWEN_Socket_Connect(GWEN_SOCKET *sp,
               addr->size)) {
     if (WSAGetLastError()!=WSAEINPROGRESS &&
         WSAGetLastError()!=WSAEWOULDBLOCK) {
-      DBG_ERROR(GWEN_LOGDOMAIN, "Error %d (%s)",
+      DBG_INFO(GWEN_LOGDOMAIN, "Error %d (%s)",
                 WSAGetLastError(),
 		h_strerror(WSAGetLastError()));
       return GWEN_Error_new(0,
@@ -1409,7 +1409,7 @@ GWEN_ERRORCODE GWEN_Socket_SetBlocking(GWEN_SOCKET *sp,
   assert(sp);
   fl=!b;
   if (ioctlsocket(sp->socket,FIONBIO,&fl)) {
-    DBG_ERROR(GWEN_LOGDOMAIN, "Error %d (%s)",
+    DBG_INFO(GWEN_LOGDOMAIN, "Error %d (%s)",
               WSAGetLastError(),
               h_strerror(WSAGetLastError()));
     return GWEN_Error_new(0,
