@@ -1,7 +1,7 @@
 /***************************************************************************
   $RCSfile$
                              -------------------
-    cvs         : $Id: process_p.h 303 2004-04-08 10:37:38Z aquamaniac $
+    cvs         : $Id: process_p.h 1108 2007-01-09 14:52:56Z christian $
     begin       : Sun Dec 28 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -68,7 +68,7 @@ GWEN_ERRORCODE GWEN_BufferedIO_WinFile__Write(GWEN_BUFFEREDIO *dm,
                                               int *size,
                                               int timeout);
 GWEN_ERRORCODE GWEN_BufferedIO_WinFile__Close(GWEN_BUFFEREDIO *dm);
-void GWEN_BufferedIO_WinFile_FreeData(void *bp, void *p);
+void GWENHYWFAR_CB GWEN_BufferedIO_WinFile_FreeData(void *bp, void *p);
 
 GWEN_BUFFEREDIO *GWEN_BufferedIO_WinFile_new(HANDLE fd);
 
