@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: dbio_p.h 831 2005-08-17 13:55:59Z aquamaniac $
+ cvs         : $Id: dbio_p.h 1108 2007-01-09 14:52:56Z christian $
  begin       : Wed Mar 31 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -40,7 +40,7 @@ typedef struct GWEN_DBIO_PLUGIN GWEN_DBIO_PLUGIN;
 struct GWEN_DBIO_PLUGIN {
   GWEN_DBIO_PLUGIN_FACTORYFN factoryFn;
 };
-void GWEN_DBIO_Plugin_FreeData(void *bp, void *p);
+void GWENHYWFAR_CB GWEN_DBIO_Plugin_FreeData(void *bp, void *p);
 
 
 
