@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: xsd.c,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: xsd.c,v 1.4 2004/12/22 17:02:04 aquamaniac Exp $
+ cvs         : $Id: xsd.c 656 2004-12-22 17:02:05Z aquamaniac $
  begin       : Sat Jun 28 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
