@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: showuser.c 967 2006-01-23 05:11:37Z aquamaniac $
+ cvs         : $Id: showuser.c 1088 2006-09-20 17:05:48Z martin $
  begin       : Tue May 03 2005
  copyright   : (C) 2005 by Martin Preuss
  email       : martin@libchipcard.de
@@ -124,7 +124,7 @@ int showUser(GWEN_DB_NODE *dbArgs, int argc, char **argv) {
     DBG_ERROR(0, "Plugin not found");
     return 3;
   }
-  DBG_ERROR(0, "Plugin found");
+  DBG_INFO(0, "Plugin found");
 
   ct=GWEN_CryptToken_Plugin_CreateToken(pl, 0, tname);
   if (ct==0) {
